# Mediawiki messages

A schema package for [Mediawiki](http://github.com/fedora-infra/mediawiki-messages).

See the [detailed documentation](https://fedora-messaging.readthedocs.io/en/latest/messages.html) on packaging your schemas.
